/*
 * gexiv2-metadata.h
 *
 * Author(s)
 * 	Jim Nelson <jim@yorba.org>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

#ifndef GEXIV2_H
#define GEXIV2_H

#include <gexiv2/gexiv2-metadata.h>
#include <gexiv2/gexiv2-preview-properties.h>
#include <gexiv2/gexiv2-preview-image.h>
#include <gexiv2/gexiv2-log.h>
#include <gexiv2/gexiv2-startup.h>
#include <gexiv2/gexiv2-version.h>

#endif /* GEXIV2_H */
